# KyreneCovidChecker

I'm still working out the details of bundling but you should be able to first install `build`

`pip install build`

and then build the package with `python -m build`

finally you should be able to run with `python -m KyreneCovidChecker` from the command line

The output should look something like this: ![demo of the covid checker](img/demo.gif)